@@ -10,6 +10,7 @@ from dust_extinction.parameter_averages import (
     M14,
     G16,
     F19,
+    D22,
 )
 from dust_extinction.shapes import FM90, P92, G21
 from dust_extinction.averages import (
@@ -25,10 +26,11 @@ from dust_extinction.averages import (
     GCC09_MWAvg,
     F11_MWGC,
     G21_MWAvg,
+    D22_MWAvg,
 )
 from dust_extinction.grain_models import DBP90, WD01, D03, ZDA04, C11, J13
 
-param_ave_models_Rv = [CCM89, O94, F99, F04, VCG04, GCC09, M14, F19]
+param_ave_models_Rv = [CCM89, O94, F99, F04, VCG04, GCC09, M14, F19, D22]
 param_ave_models_Rv_fA = [G16]
 param_ave_models = param_ave_models_Rv + param_ave_models_Rv_fA
 shape_models = [FM90, P92, G21]
@@ -45,6 +47,7 @@ ave_models = [
     GCC09_MWAvg,
     F11_MWGC,
     G21_MWAvg,
+    D22_MWAvg,
 ]
 grain_models = [DBP90, WD01, D03, ZDA04, C11, J13]
 
